<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:ns10="http://jazz.net/xmlns/alm/qm/v0.1/executionworkitem/v0.1"
    xmlns:ns2="http://jazz.net/xmlns/alm/qm/v0.1/" xmlns:ns3="http://jazz.net/xmlns/alm/v0.1/"
    xmlns:ns4="http://schema.ibm.com/vega/2008/"
    xmlns:ns5="http://jazz.net/xmlns/alm/qm/v0.1/testscript/v0.1/"
    xmlns:ns6="http://jazz.net/xmlns/alm/qm/qmadapter/task/v0.1"
    xmlns:ns7="http://jazz.net/xmlns/alm/qm/qmadapter/v0.1"
    xmlns:ns8="http://jazz.net/xmlns/alm/qm/v0.1/executionresult/v0.1"
    xmlns:ns9="http://jazz.net/xmlns/alm/qm/v0.1/tsl/v0.1/" xmlns:atom="http://www.w3.org/2005/Atom"
    xmlns:time="xalan://com.ibm.rqm.xslfo.service.extension.TimeUtilsExtension"
    exclude-result-prefixes="ns10 ns9 ns8 ns7 ns6 ns5 ns4 ns3 ns2 atom dc xsl">
	
	<!-- included stylesheets -->    
	<xsl:include href="attribute-sets.xsl"/>
	<xsl:include href="wrapping-rules.xsl"/>
	<xsl:include href="xhtml-to-xslfo-ns.xsl"/>
	
	<!-- variables -->
	<xsl:variable name="lang" select="locale"/>
	<xsl:variable name="strings" select="document('fopmessages.xml')/fopmessages//*[name()=$lang]"/>
	
	<xsl:template match="transformArgs">
        <xsl:choose>
            <xsl:when test="(componentType='STAND_ALONE') or (componentType='STAND_ALONE_SUMMARY')">
                <fo:page-sequence xmlns:fo="http://www.w3.org/1999/XSL/Format" initial-page-number="1" force-page-count="no-force" 
                				  master-reference="PageMaster">
                    <fo:static-content flow-name="xsl-region-before">
                        <fo:block font-size="8pt" text-align="right">
                            <fo:page-number/> / <fo:page-number-citation ref-id="{reqNumber}"/>
                        </fo:block>
                    </fo:static-content>
                    <fo:static-content flow-name="xsl-region-after">
                    	<fo:block-container height="0.1in" padding-after="0.07in">
							<fo:block text-align="center">
								<fo:leader leader-pattern='rule' rule-thickness='1pt' leader-length='100%'/>
							</fo:block>
						</fo:block-container>
                        <fo:block text-align="center">
                            <fo:retrieve-marker retrieve-class-name="artifactUri"/>
                        </fo:block>
                    </fo:static-content>
                    <fo:flow flow-name="xsl-region-body">
                        <fo:marker marker-class-name="artifactUri">
                            <fo:block font-size="6pt">
                                <fo:basic-link external-destination="{originUrl}" color="blue" text-decoration="underline">
                                    <xsl:value-of select="originUrl"/>
                                </fo:basic-link>
                            </fo:block>
                        </fo:marker>
                        <xsl:apply-templates select="descendant::ns2:executionresult"/>
                        <fo:block id="{reqNumber}"/>
                    </fo:flow>
                </fo:page-sequence>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates select="descendant::ns2:executionresult"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
	
	
    <xsl:template match="ns2:executionresult">
		<xsl:choose>
			<xsl:when test="(../../componentType='SUMMARY') or (../../componentType='STAND_ALONE_SUMMARY') or (../../componentType='COMPOSITE_SUMMARY')">
				<xsl:choose>
					<xsl:when test="../../componentType='STAND_ALONE_SUMMARY' or (../../componentType='COMPOSITE_SUMMARY')">
						<xsl:if test="../../componentType='STAND_ALONE_SUMMARY'">
							<fo:block font-size="14pt" space-before="6mm" space-after="2mm">
								<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelSummary"/>:
								<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/titleResultsTableView"/>
							</fo:block>
						</xsl:if>
						<fo:table xsl:use-attribute-sets="artifact-table">
							<fo:table-header xsl:use-attribute-sets="artifact-table-header">
								<!-- id -->
								<fo:table-cell xsl:use-attribute-sets="border id-header">
									<fo:block><xsl:value-of select="$strings/labelId"/></fo:block>
								</fo:table-cell>
								<!-- name -->
								<fo:table-cell xsl:use-attribute-sets="border">
									<fo:block><xsl:value-of select="$strings/labelName"/></fo:block>
								</fo:table-cell>
								<!-- test case -->
								<fo:table-cell xsl:use-attribute-sets="border">
									<fo:block><xsl:value-of select="$strings/labelTestCase"/></fo:block>
								</fo:table-cell>
								<!-- test script -->
								<fo:table-cell xsl:use-attribute-sets="border">
									<fo:block><xsl:value-of select="$strings/labelTestScript"/></fo:block>
								</fo:table-cell>
								<!-- end time -->
								<fo:table-cell xsl:use-attribute-sets="border timestamp-header">
									<fo:block><xsl:value-of select="$strings/endTime"/></fo:block>
								</fo:table-cell>
								<!-- state -->
								<fo:table-cell xsl:use-attribute-sets="border" width="32">
									<fo:block><xsl:value-of select="$strings/labelState"/></fo:block>
								</fo:table-cell>
							</fo:table-header>
							<fo:table-body>
								<xsl:call-template name="summarytablerows"/>
							</fo:table-body>
						</fo:table>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="summarytablerows"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:when test="(../../componentType='COMPOSITE') and (../../recursive)">
				<fo:wrapper>
					<xsl:call-template name="recursivetablerows"/>
					<fo:block xmlns:fo="http://www.w3.org/1999/XSL/Format">
						<xsl:attribute name="id">
                            <xsl:value-of select="dc:identifier" />
                        </xsl:attribute>
	                	<!-- NAME -->
	                    <fo:block font-size="14pt" space-before="2mm" space-after="2mm" border-after-style="solid" border-after-width="thin">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelName"/>: 
	                    	<xsl:value-of select="dc:title"/>
	                    </fo:block>
	                	<!-- MODIFIED DATE -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelModifiedDate"/>: 
	                    	<xsl:value-of select="ns3:updated"/>
	                    </fo:block>
	                	<!-- OWNER -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelOwnedBy"/>: 
	                    	<xsl:value-of select="ns3:owner"/>
	                    </fo:block>
	                	<!-- HOST NAME -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/hostname"/>: 
	                    	<xsl:value-of select="ns8:machine"/>
	                    </fo:block>
	                	<!-- START TIME -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelStartTime"/>: 
	                    	<xsl:value-of select="ns8:starttime"/>
	                    </fo:block>
	                	<!-- END TIME -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelEndTime"/>: 
	                    	<xsl:value-of select="ns8:endtime"/>
	                    </fo:block>
	                	<!-- TESTSCRIPT -->
	                    <fo:block space-before="2mm">
	                    	<xsl:apply-templates select="ns2:testscript"/>
	                    </fo:block>
	                    <!-- RESULT -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelLastResult"/>: 
	                    	<xsl:choose>
	                    		<!-- passed -->
	                            <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.passed'">
	                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelPassed"/> </xsl:when>
	                    		<!-- failed -->
	                            <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.failed'">
	                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelFailed"/> </xsl:when>
	                            <!-- blocked -->
	                    		<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.blocked'">
	                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelBlocked"/> </xsl:when>
	                            <!-- complete -->
	                    		<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.complete'">
	                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelComplete"/> </xsl:when>
	                            <!-- inconclusive -->
	                    		<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.inconclusive'">
	                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelInconclusive"/> </xsl:when>
	                    		<!-- error -->
	                            <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.error'">
	                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelError"/> </xsl:when>
	                            <xsl:otherwise> -- </xsl:otherwise>
	                        </xsl:choose>
	                    </fo:block>
	                	<!-- EXECUTION WORK ITEM -->
	                    <fo:block space-before="2mm">
	                    	<xsl:apply-templates select="descendant::ns2:executionworkitem"/>
	                    </fo:block>
	                	<!-- WEIGHT DISTRIBUTION -->
	                    <fo:block font-size="14pt" space-before="2mm" space-after="2mm" border-after-style="solid" border-after-width="thin">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/weightDistribution"/>
	                    </fo:block>
	                	<!-- POINTS PASSED -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelPassed"/>: 
	                    	<xsl:value-of select="ns8:pointspassed"/>
	                    </fo:block>
	                	<!-- POINTS FAILED -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelFailed"/>: 
	                    	<xsl:value-of select="ns8:pointsfailed"/>
	                    </fo:block>
	                	<!-- POINTS INCONCLUSIVE -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelInconclusive"/>: 
	                    	<xsl:value-of select="ns8:pointsinconclusive"/>
	                    </fo:block>
	                	<!-- POINTS BLOCKED -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelBlocked"/>: 
	                    	<xsl:value-of select="ns8:pointsblocked"/>
	                    </fo:block>
	                	<!-- POINTS ATTEMPTED -->
	                    <fo:block space-before="2mm">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelAttempted"/>: 
	                    	<xsl:value-of select="ns8:pointsattempted"/>
	                    </fo:block>
	                	<!-- DEFECT TABLE -->
	                    <fo:block font-size="14pt" space-before="2mm" space-after="2mm" border-after-style="solid" border-after-width="thin">
	                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/Defects"/>
	                    </fo:block>
	                    <fo:block>
		                    <xsl:choose>
			                    <xsl:when test="ns2:defect/fo:table/fo:table-header">
				                    <fo:table border="0.5pt solid black">
										<xsl:copy-of select="ns2:defect/fo:table/fo:table-header"/>
										<fo:table-body>
											<xsl:copy-of select="ns2:defect/fo:table/fo:table-body/fo:table-row"/>
											<xsl:copy-of select="ns2:defect/fo:table-row"/>
										</fo:table-body>
								    </fo:table>
							    </xsl:when>
							</xsl:choose>
	                    </fo:block>
	                	<!-- RESULT DETAILS -->
	                    <fo:block font-size="14pt" space-before="2mm" space-after="2mm"	border-after-style="solid" border-after-width="thin">
	                    	<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/resultDetails"/>
	                    </fo:block>
						<fo:block font-size="10pt">
							<xsl:apply-templates select="ns8:details/*"/>		<!-- applies template for rich text section -->
						</fo:block>
	                	<xsl:if test="../../datapoolsize > 0">
	                		<fo:table border="0.5pt solid black" font-size="8pt">
	                			<fo:table-header>
	                				<fo:table-cell background-color="rgb(222,242,236)">
	                					<fo:block-container overflow="hidden">
	                						<fo:block font-weight="bold" text-align="left">#</fo:block>
	                					</fo:block-container>
	                				</fo:table-cell>
	                				<!-- TYPE -->
	                				<fo:table-cell background-color="rgb(222,242,236)">
	                					<fo:block-container overflow="hidden">
	                						<fo:block font-weight="bold" text-align="left">
	                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelType"/>
	                						</fo:block>
	                					</fo:block-container>
	                				</fo:table-cell>
	                				<!-- RESULT -->
	                				<fo:table-cell background-color="rgb(222,242,236)">
	                					<fo:block-container overflow="hidden">
	                						<fo:block font-weight="bold" text-align="left">
	                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelResult"/>
	                						</fo:block>
	                					</fo:block-container>
	                				</fo:table-cell>
	                				<!-- LABEL DESCRIPTION -->
	                				<fo:table-cell background-color="rgb(222,242,236)">
	                					<fo:block-container overflow="hidden">
	                						<fo:block font-weight="bold" text-align="left">
	                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labeldescription"/>
	                						</fo:block>
	                					</fo:block-container>
	                				</fo:table-cell>
	                				<!-- EXPECTED RESULT -->
	                				<fo:table-cell background-color="rgb(222,242,236)">
	                					<fo:block-container overflow="hidden">
	                						<fo:block font-weight="bold" text-align="left">
	                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelExpectedResult"/>
	                						</fo:block>
	                					</fo:block-container>
	                				</fo:table-cell>
	                				<!-- ACTUAL RESULT -->
	                				<fo:table-cell background-color="rgb(222,242,236)">
	                					<fo:block-container overflow="hidden">
	                						<fo:block font-weight="bold" text-align="left">
	                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelActualResult"/>
	                						</fo:block>
	                					</fo:block-container>
	                				</fo:table-cell>
	                				<!-- ATTACHMENTS -->
	                				<fo:table-cell background-color="rgb(222,242,236)">
	                					<fo:block-container overflow="hidden">
	                						<fo:block font-weight="bold" text-align="left">Attachments</fo:block>
	                					</fo:block-container>
	                				</fo:table-cell>
	                				<!-- DEFECTS -->
	                				<fo:table-cell background-color="rgb(222,242,236)">
	                					<fo:block-container overflow="hidden">
	                						<fo:block font-weight="bold" text-align="left">Defects</fo:block>
	                					</fo:block-container>
	                				</fo:table-cell>
	                				<!-- COMMENTS -->
	                				<fo:table-cell background-color="rgb(222,242,236)">
	                					<fo:block-container overflow="hidden">
	                						<fo:block font-weight="bold" text-align="left">Comments</fo:block>
	                					</fo:block-container>
	                				</fo:table-cell>
	                			</fo:table-header>
	                			<fo:table-body>
	                				<xsl:call-template name="for.loop">
	                					<xsl:with-param name="i">1</xsl:with-param>
	                					<xsl:with-param name="count"> <xsl:value-of select="../../datapoolsize"/> </xsl:with-param>
	                					<xsl:with-param name="k" select="1"/>
	                				</xsl:call-template>
	                			</fo:table-body>
	                		</fo:table> 
	                	</xsl:if>
	                </fo:block>
                </fo:wrapper>
			</xsl:when>
			<xsl:otherwise>
                <fo:block xmlns:fo="http://www.w3.org/1999/XSL/Format">
                	<!-- NAME -->
                    <fo:block font-size="14pt" space-before="2mm" space-after="2mm" border-after-style="solid" border-after-width="thin">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelName"/>: 
                    	<xsl:value-of select="dc:title"/>
                    </fo:block>
                	<!-- MODIFIED DATE -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelModifiedDate"/>: 
                    	<xsl:value-of select="ns3:updated"/>
                    </fo:block>
                	<!-- OWNER -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelOwnedBy"/>: 
                    	<xsl:value-of select="ns3:owner"/>
                    </fo:block>
                	<!-- HOST NAME -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/hostname"/>: 
                    	<xsl:value-of select="ns8:machine"/>
                    </fo:block>
                	<!-- START TIME -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelStartTime"/>: 
                    	<xsl:value-of select="ns8:starttime"/>
                    </fo:block>
                	<!-- END TIME -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelEndTime"/>: 
                    	<xsl:value-of select="ns8:endtime"/>
                    </fo:block>
                	<!-- TESTSCRIPT -->
                    <fo:block space-before="2mm">
                    	<xsl:apply-templates select="ns2:testscript"/>
                    </fo:block>
                    <!-- RESULT -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelLastResult"/>: 
                    	<xsl:choose>
                    		<!-- passed -->
                            <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.passed'">
                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelPassed"/> </xsl:when>
                    		<!-- failed -->
                            <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.failed'">
                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelFailed"/> </xsl:when>
                            <!-- blocked -->
                    		<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.blocked'">
                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelBlocked"/> </xsl:when>
                            <!-- complete -->
                    		<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.complete'">
                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelComplete"/> </xsl:when>
                            <!-- inconclusive -->
                    		<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.inconclusive'">
                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelInconclusive"/> </xsl:when>
                    		<!-- error -->
                            <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.error'">
                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelError"/> </xsl:when>
                            <xsl:otherwise> -- </xsl:otherwise>
                        </xsl:choose>
                    </fo:block>
                	<!-- EXECUTION WORK ITEM -->
                    <fo:block space-before="2mm">
                    	<xsl:apply-templates select="descendant::ns2:executionworkitem"/>
                    </fo:block>
                	<!-- WEIGHT DISTRIBUTION -->
                    <fo:block font-size="14pt" space-before="2mm" space-after="2mm" border-after-style="solid" border-after-width="thin">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/weightDistribution"/>
                    </fo:block>
                	<!-- POINTS PASSED -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelPassed"/>: 
                    	<xsl:value-of select="ns8:pointspassed"/>
                    </fo:block>
                	<!-- POINTS FAILED -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelFailed"/>: 
                    	<xsl:value-of select="ns8:pointsfailed"/>
                    </fo:block>
                	<!-- POINTS INCONCLUSIVE -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelInconclusive"/>: 
                    	<xsl:value-of select="ns8:pointsinconclusive"/>
                    </fo:block>
                	<!-- POINTS BLOCKED -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelBlocked"/>: 
                    	<xsl:value-of select="ns8:pointsblocked"/>
                    </fo:block>
                	<!-- POINTS ATTEMPTED -->
                    <fo:block space-before="2mm">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelAttempted"/>: 
                    	<xsl:value-of select="ns8:pointsattempted"/>
                    </fo:block>
                	<!-- DEFECT TABLE -->
                    <fo:block font-size="14pt" space-before="2mm" space-after="2mm" border-after-style="solid" border-after-width="thin">
                        <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/Defects"/>
                    </fo:block>
                    <fo:block>
	                    <xsl:choose>
		                    <xsl:when test="ns2:defect/fo:table/fo:table-header">
			                    <fo:table border="0.5pt solid black">
									<xsl:copy-of select="ns2:defect/fo:table/fo:table-header"/>
									<fo:table-body>
										<xsl:copy-of select="ns2:defect/fo:table/fo:table-body/fo:table-row"/>
										<xsl:copy-of select="ns2:defect/fo:table-row"/>
									</fo:table-body>
							    </fo:table>
						    </xsl:when>
						</xsl:choose>
                    </fo:block>
                	<!-- RESULT DETAILS -->
                    <fo:block font-size="14pt" space-before="2mm" space-after="2mm"	border-after-style="solid" border-after-width="thin">
                    	<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/resultDetails"/>
                    </fo:block>
					<fo:block font-size="10pt">
						<xsl:apply-templates select="ns8:details/*"/>		<!-- applies template for rich text section -->
					</fo:block>
                	<xsl:if test="../../datapoolsize > 0">
                		<fo:table border="0.5pt solid black" font-size="8pt">
                			<fo:table-header>
                				<fo:table-cell background-color="rgb(222,242,236)">
                					<fo:block-container overflow="hidden">
                						<fo:block font-weight="bold" text-align="left">#</fo:block>
                					</fo:block-container>
                				</fo:table-cell>
                				<!-- TYPE -->
                				<fo:table-cell background-color="rgb(222,242,236)">
                					<fo:block-container overflow="hidden">
                						<fo:block font-weight="bold" text-align="left">
                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelType"/>
                						</fo:block>
                					</fo:block-container>
                				</fo:table-cell>
                				<!-- RESULT -->
                				<fo:table-cell background-color="rgb(222,242,236)">
                					<fo:block-container overflow="hidden">
                						<fo:block font-weight="bold" text-align="left">
                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelResult"/>
                						</fo:block>
                					</fo:block-container>
                				</fo:table-cell>
                				<!-- LABEL DESCRIPTION -->
                				<fo:table-cell background-color="rgb(222,242,236)">
                					<fo:block-container overflow="hidden">
                						<fo:block font-weight="bold" text-align="left">
                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labeldescription"/>
                						</fo:block>
                					</fo:block-container>
                				</fo:table-cell>
                				<!-- EXPECTED RESULT -->
                				<fo:table-cell background-color="rgb(222,242,236)">
                					<fo:block-container overflow="hidden">
                						<fo:block font-weight="bold" text-align="left">
                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelExpectedResult"/>
                						</fo:block>
                					</fo:block-container>
                				</fo:table-cell>
                				<!-- ACTUAL RESULT -->
                				<fo:table-cell background-color="rgb(222,242,236)">
                					<fo:block-container overflow="hidden">
                						<fo:block font-weight="bold" text-align="left">
                							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelActualResult"/>
                						</fo:block>
                					</fo:block-container>
                				</fo:table-cell>
                				<!-- ATTACHMENTS -->
                				<fo:table-cell background-color="rgb(222,242,236)">
                					<fo:block-container overflow="hidden">
                						<fo:block font-weight="bold" text-align="left">Attachments</fo:block>
                					</fo:block-container>
                				</fo:table-cell>
                				<!-- DEFECTS -->
                				<fo:table-cell background-color="rgb(222,242,236)">
                					<fo:block-container overflow="hidden">
                						<fo:block font-weight="bold" text-align="left">Defects</fo:block>
                					</fo:block-container>
                				</fo:table-cell>
                				<!-- COMMENTS -->
                				<fo:table-cell background-color="rgb(222,242,236)">
                					<fo:block-container overflow="hidden">
                						<fo:block font-weight="bold" text-align="left">Comments</fo:block>
                					</fo:block-container>
                				</fo:table-cell>
                			</fo:table-header>
                			<fo:table-body>
                				<xsl:call-template name="for.loop">
                					<xsl:with-param name="i">1</xsl:with-param>
                					<xsl:with-param name="count"> <xsl:value-of select="../../datapoolsize"/> </xsl:with-param>
                					<xsl:with-param name="k" select="1"/>
                				</xsl:call-template>
                			</fo:table-body>
                		</fo:table> 
                	</xsl:if>
                </fo:block>
			</xsl:otherwise>
		</xsl:choose>
    </xsl:template>
    
    
    <xsl:template match="ns2:testscript">
		<xsl:for-each select="fo:block">
			<xsl:for-each select="fo:block">
				<xsl:if test="position() = 2">
					<fo:block space-before="2mm"> 
						<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelDatapool"/>:
						<xsl:choose>
							<xsl:when test="fo:basic-link/@external-destination">
								<fo:basic-link color="blue" text-decoration="underline">
									<xsl:attribute name="external-destination">
										<xsl:value-of select="fo:basic-link/@external-destination"/>
									</xsl:attribute>
									<xsl:value-of select="fo:basic-link"/>
								</fo:basic-link>
							</xsl:when>
							<xsl:otherwise>
					 			<xsl:choose>
									<xsl:when test="fo:basic-link">
										<xsl:value-of select="fo:basic-link"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelUnassigned"/>
									</xsl:otherwise>
					 			</xsl:choose>
							</xsl:otherwise>
				  		</xsl:choose>
			  		</fo:block>
				</xsl:if>
			</xsl:for-each>
		</xsl:for-each>
    </xsl:template>
    
    
    <xsl:template match="ns2:executionworkitem">
		<fo:block space-before="2mm">
			<xsl:for-each select="fo:table/fo:table-body/fo:table-row">
				<xsl:for-each select="fo:table-cell">
					<!-- TEST ENVIRONMENT -->
					<xsl:if test="position() = 2">
						<fo:block space-before="2mm">
							<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelTestEnvironment"/>:
							<xsl:value-of select="fo:block-container/fo:block" />							    
						</fo:block>
					</xsl:if>
					<!-- TESTCASE -->
					<xsl:if test="position() = 3">
			    		<fo:block space-before="2mm">
			    			<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelTestCase"/> :
							<fo:basic-link color="blue" text-decoration="underline">
					        	<xsl:attribute name="external-destination">
									<xsl:value-of select="../../../../../ns2:testcase/@href"/>
								</xsl:attribute>	
								<xsl:value-of select="fo:block-container/fo:block" />
							</fo:basic-link>
						</fo:block>
					</xsl:if>
					<!-- TEST PLAN -->
					<xsl:if test="position() = 4">
			    		<fo:block space-before="2mm">
			    			<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelTestPlan"/>:
							<xsl:choose>
								<xsl:when test="../../../../../../../testplanlink">
							    	<fo:basic-link color="blue" text-decoration="underline">
						          		<xsl:attribute name="external-destination">
						           			<xsl:value-of select="../../../../../../../testplanlink"/>
						          		</xsl:attribute>	
						          		<xsl:value-of select="fo:block-container/fo:block" />
						        	</fo:basic-link>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelUnassigned"/>
								</xsl:otherwise>
						  	</xsl:choose>
						</fo:block>
					</xsl:if>
					<!-- TEST SCRIPT -->
					<xsl:if test="position() = 5">
			    		<fo:block space-before="2mm">
				    		<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelTestScript"/>:
			    			<xsl:if test="../../../../../ns2:testscript/@href">
			    				<fo:basic-link color="blue" text-decoration="underline">
			    					<xsl:attribute name="external-destination">
			    						<xsl:value-of select="../../../../../ns2:testscript/@href"/>
			    					</xsl:attribute>	
			    					<xsl:value-of select="fo:block-container/fo:block"/>
			    				</fo:basic-link>	
			    			</xsl:if>
						</fo:block>
					</xsl:if>
					<!-- TEST MILESTONE -->
					<xsl:if test="position() = 6">
						<fo:block space-before="2mm">
				    		<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelTestMilestone"/> :
							<xsl:choose>
								<xsl:when test="../../../../../../../testplanlink">
									<fo:basic-link color="blue" text-decoration="underline">
								    	<xsl:attribute name="external-destination">
											<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelUnassigned"/>
								           	<xsl:value-of select="../../../../../../../testphaselink"/>
										</xsl:attribute>	
						  				<xsl:value-of select="fo:block-container/fo:block" />
									</fo:basic-link>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelUnassigned"/>
								</xsl:otherwise>
							</xsl:choose>
					  	</fo:block>
					</xsl:if>
					<!-- WEIGHT -->
					<xsl:if test="position() = 10">
			    		<fo:block space-before="2mm">
			    			<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelWeight"/> :
							<xsl:value-of select="fo:block-container/fo:block" />
						</fo:block>
					</xsl:if>
				</xsl:for-each>
			</xsl:for-each>
		</fo:block>
	</xsl:template>


	<xsl:template name="for.loop">
		<xsl:param name="i"/>
	 	<xsl:param name="count"/>
	 	<xsl:param name="k"/>
	 	
		<xsl:if test="$i &lt;= $count">
	 		<xsl:call-template name="inner.loop">
		 		<xsl:with-param name="j">1</xsl:with-param>
		 		<xsl:with-param name="countInner"> <xsl:value-of select="count(ns2:testscript/fo:block/fo:table/fo:table-body/fo:table-row)"/> </xsl:with-param>
		 		<xsl:with-param name="k" select="$k"/>
			</xsl:call-template>
	 	</xsl:if>
		<xsl:if test="$i &lt;= $count">
	  		<xsl:call-template name="for.loop">
	   			<xsl:with-param name="i"> <xsl:value-of select="$i + 1"/> </xsl:with-param>
	   			<xsl:with-param name="count"> <xsl:value-of select="$count"/> </xsl:with-param>
	   			<xsl:with-param name="k"> <xsl:value-of select="$k + count(ns2:testscript/fo:block/fo:table/fo:table-body/fo:table-row)"/> </xsl:with-param>
	  		</xsl:call-template>
	 	</xsl:if>
	</xsl:template>
	
	
	<xsl:template name="inner.loop">
		 <xsl:param name="j"/>
	 	 <xsl:param name="countInner"/>
	 	 <xsl:param name="k"/>
		
		 <xsl:if test="$j &lt;= $countInner">
		 	<xsl:for-each select="ns2:testscript/fo:block/fo:table/fo:table-body/fo:table-row">
		 		<xsl:if test="position() = $j">
		 			<fo:table-row font-size="8pt">
						<xsl:for-each select="fo:table-cell">
							<xsl:if test="position() = 1">
								<fo:table-cell padding="1pt" border="0.5pt solid black">
			                        <fo:block-container overflow="hidden">
			                            <fo:block> <xsl:value-of select="$k"/> </fo:block>
			                        </fo:block-container>
			                    </fo:table-cell>
							</xsl:if>
							<xsl:if test="position() = 2">
								<fo:table-cell padding="1pt" border="0.5pt solid black">
			                        <fo:block-container overflow="hidden">
			                            <fo:block> <xsl:value-of select="fo:block-container/fo:block"/> </fo:block>
			                        </fo:block-container>
			                    </fo:table-cell>
							</xsl:if>
							<!-- STEP RESULT -->
							<xsl:if test="position() = 3">
								<fo:table-cell padding="1pt" border="0.5pt solid black">
			                        <fo:block-container overflow="hidden">
			                            <fo:block>
			                            	<xsl:for-each select="ancestor::ns2:executionresult/ns2:stepResults/ns2:stepResult">
			                            		 <xsl:if test="position() = $k">
			                            		 	<xsl:choose>
			                            		 		<!-- passed -->
			                            		 		<xsl:when test="@result='com.ibm.rqm.execution.common.state.passed'">
						                                	<xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelPassed"/> </xsl:when>
			                            		 		<!-- failed -->
						                           		<xsl:when test="@result='com.ibm.rqm.execution.common.state.failed'">
							                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelFailed"/> </xsl:when>
			                            		 		<!-- blocked -->
							                            <xsl:when test="@result='com.ibm.rqm.execution.common.state.blocked'">
							                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelBlocked"/> </xsl:when>
			                            		 		<!-- complete -->
							                            <xsl:when test="@result='com.ibm.rqm.execution.common.state.complete'">
							                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelComplete"/> </xsl:when>
			                            		 		<!-- inconclusive -->
							                            <xsl:when test="@result='com.ibm.rqm.execution.common.state.inconclusive'">
							                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelInconclusive"/> </xsl:when>
			                            		 		<!-- error -->
							                            <xsl:when test="@result='com.ibm.rqm.execution.common.state.error'">
							                                <xsl:value-of select="document('fopmessages.xml')/fopmessages//*[name()=$lang]/labelError"/> </xsl:when>
							                            <xsl:otherwise> -- </xsl:otherwise>
						                           	</xsl:choose>
			                            		 </xsl:if>
			                            	</xsl:for-each>
			                            </fo:block>
			                        </fo:block-container>
			                    </fo:table-cell>
							</xsl:if>
			                <xsl:if test="position() = 3">
								<fo:table-cell padding="1pt" border="0.5pt solid black">
			                        <fo:block-container overflow="hidden">
			                            <fo:block>
											<xsl:choose>
												<!-- keyword step -->
												<xsl:when test="fo:block/fo:block/fo:basic-link">
													<xsl:copy-of select="fo:block/fo:block"/> </xsl:when>
												<!-- non-keyword step -->
												<xsl:otherwise>
													<xsl:value-of select="fo:block-container/fo:block"/> </xsl:otherwise>
											</xsl:choose>
			                            </fo:block>
			                        </fo:block-container>
			                    </fo:table-cell>
							</xsl:if>
							<xsl:if test="position() = 4">
								<fo:table-cell padding="1pt" border="0.5pt solid black">
			                        <fo:block-container overflow="hidden">
			                            <fo:block> <xsl:value-of select="fo:block-container/fo:block"/> </fo:block>
			                        </fo:block-container>
			                    </fo:table-cell>
							</xsl:if>
							<xsl:if test="position() = 4">
								<fo:table-cell padding="1pt" border="0.5pt solid black">
			                        <fo:block-container overflow="hidden">
			                            <fo:block>
											<xsl:for-each select="ancestor::ns2:executionresult/ns2:stepResults/ns2:stepResult">
												<xsl:if test="position() = $k"> 
													<xsl:value-of select="@actualResult"/> 
												</xsl:if>
			                            	</xsl:for-each>  
			                            </fo:block>
			                        </fo:block-container>
			                    </fo:table-cell>
							</xsl:if>
							<xsl:if test="position() = 4">
								<fo:table-cell padding="1pt" border="0.5pt solid black">
									<fo:block-container overflow="hidden">
										<fo:block>
											<xsl:for-each select="ancestor::ns2:executionresult/ns2:stepResults/ns2:stepResult">
												<xsl:if test="position() = $k">
													<xsl:for-each select="ns2:properties/ns2:property">
														<xsl:if test="@propertyType='attachmentView'">
															<xsl:value-of select ="@propertyValue"/> 
														</xsl:if>
				                            		 </xsl:for-each>
												</xsl:if>		                            	
			                            	</xsl:for-each>  
			                            </fo:block>
			                        </fo:block-container>
			                    </fo:table-cell>
							</xsl:if>
							<xsl:if test="position() = 4">
								<fo:table-cell padding="1pt" border="0.5pt solid black">
			                        <fo:block-container overflow="hidden">
			                        	<fo:block>
			                        		<xsl:for-each select="ancestor::ns2:executionresult/ns2:stepResults/ns2:stepResult">
			                        			<xsl:if test="position() = $k">
			                        				<xsl:for-each select="ns2:properties/ns2:property">
			                        					<xsl:if test="@propertyType='defectView'">
			                        						<xsl:value-of select ="@propertyValue"/>
			                        					</xsl:if>
			                        				</xsl:for-each>
			                        			</xsl:if>
			                        		</xsl:for-each>
			                        	</fo:block>
			                        </fo:block-container>
								</fo:table-cell>
							</xsl:if>
							<xsl:if test="position() = 4">
								<fo:table-cell padding="1pt" border="0.5pt solid black">
			                        <fo:block-container overflow="hidden">
			                        	<fo:block>
			                        		<xsl:for-each select="ancestor::ns2:executionresult/ns2:stepResults/ns2:stepResult">
			                        			<xsl:if test="position() = $k">
			                        				<xsl:for-each select="ns2:properties/ns2:property">
			                        					<xsl:if test="@propertyType='commentView'">
			                        						<xsl:value-of select ="@propertyValue"/>
			                        					</xsl:if>
			                        				</xsl:for-each>
			                        			</xsl:if>
			                        		</xsl:for-each>
			                        	</fo:block>
			                        </fo:block-container>
								</fo:table-cell>
							</xsl:if>
						</xsl:for-each>
		 			</fo:table-row>
		 		</xsl:if>
		 	</xsl:for-each>
		</xsl:if>
		<xsl:if test="$j &lt;= $countInner">
			<xsl:call-template name="inner.loop">
				<xsl:with-param name="j"> <xsl:value-of select="$j + 1"/> </xsl:with-param>
				<xsl:with-param name="countInner"> <xsl:value-of select="$countInner"/> </xsl:with-param>
				<xsl:with-param name="k" select="$k + 1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<!-- recursive table rows -->
	<xsl:template name="recursivetablerows">
		<fo:table-row>
			<!-- id -->
			<fo:table-cell xsl:use-attribute-sets="border id-cell">
				<fo:block><xsl:value-of select="//generatedId"/></fo:block>
			</fo:table-cell>
			<!-- name -->
			<fo:table-cell xsl:use-attribute-sets="border">
				<fo:block>
					<fo:basic-link internal-destination="{dc:identifier}" xsl:use-attribute-sets="simple-link">
						<xsl:apply-templates select="dc:title"/>
					</fo:basic-link>	
				</fo:block>
			</fo:table-cell>
			<!-- test case -->
			<fo:table-cell xsl:use-attribute-sets="border">
				<fo:block><xsl:apply-templates select="../../testcasename"/></fo:block>
			</fo:table-cell>
			<!-- test script -->
			<fo:table-cell xsl:use-attribute-sets="border">
				<fo:block><xsl:apply-templates select="../../testscriptname"/></fo:block>
			</fo:table-cell>
			<!-- end time -->
			<fo:table-cell xsl:use-attribute-sets="border timestamp-cell">
				<fo:block><xsl:value-of select="time:formatTimestamp(ns8:endtime)"/></fo:block>
			</fo:table-cell>
			<!-- state -->
			<fo:table-cell xsl:use-attribute-sets="border">
				<fo:block>
					<xsl:choose>
						<!-- passed -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.passed'">
							<xsl:value-of select="$strings/labelPassed"/></xsl:when>
						<!-- failed -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.failed'">
							<xsl:value-of select="$strings/labelFailed"/></xsl:when>
						<!-- blocked -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.blocked'">
							<xsl:value-of select="$strings/labelBlocked"/></xsl:when>
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.part_blocked'">
							<xsl:value-of select="$strings/labelPartBlocked"/></xsl:when>
						<!-- complete -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.complete'">
							<xsl:value-of select="$strings/labelComplete"/></xsl:when>
						<!-- inconclusive -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.inconclusive'">
							<xsl:value-of select="$strings/labelInconclusive"/></xsl:when>
						<!-- error -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.error'">
							<xsl:value-of select="$strings/labelError"/></xsl:when>
						<!-- perm fail -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.perm_failed'">
							<xsl:value-of select="$strings/labelPermFailed"/></xsl:when>
						<!-- deferred -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.deferred'">
							<xsl:value-of select="$strings/labelDeferred"/></xsl:when>
						<!-- default -->
						<xsl:otherwise>
							<xsl:apply-templates select="ns3:state"/></xsl:otherwise>
					</xsl:choose>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>
	
	<!-- summary table rows -->
	<xsl:template name="summarytablerows">
		<fo:table-row>
			<!-- id -->
			<fo:table-cell xsl:use-attribute-sets="border id-cell">
				<fo:block><xsl:value-of select="//generatedId"/></fo:block>
			</fo:table-cell>
			<!-- name -->
			<fo:table-cell xsl:use-attribute-sets="border">
				<fo:block><xsl:apply-templates select="dc:title"/></fo:block>
			</fo:table-cell>
			<!-- test case -->
			<fo:table-cell xsl:use-attribute-sets="border">
				<fo:block><xsl:apply-templates select="../../testcasename"/></fo:block>
			</fo:table-cell>
			<!-- test script -->
			<fo:table-cell xsl:use-attribute-sets="border">
				<fo:block><xsl:apply-templates select="../../testscriptname"/></fo:block>
			</fo:table-cell>
			<!-- end time -->
			<fo:table-cell xsl:use-attribute-sets="border timestamp-cell">
				<fo:block><xsl:value-of select="time:formatTimestamp(ns8:endtime)"/></fo:block>
			</fo:table-cell>
			<!-- state -->
			<fo:table-cell xsl:use-attribute-sets="border">
				<fo:block>
					<xsl:choose>
						<!-- passed -->
                        <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.passed'">
                            <xsl:value-of select="$strings/labelPassed"/></xsl:when>
						<!-- failed -->
                        <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.failed'">
                            <xsl:value-of select="$strings/labelFailed"/></xsl:when>
						<!-- blocked -->
                        <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.blocked'">
                            <xsl:value-of select="$strings/labelBlocked"/></xsl:when>
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.part_blocked'">
							<xsl:value-of select="$strings/labelPartBlocked"/></xsl:when>
						<!-- complete -->
                        <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.complete'">
                            <xsl:value-of select="$strings/labelComplete"/></xsl:when>
						<!-- inconclusive -->
                        <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.inconclusive'">
                            <xsl:value-of select="$strings/labelInconclusive"/></xsl:when>
						<!-- error -->
                        <xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.error'">
                            <xsl:value-of select="$strings/labelError"/></xsl:when>
						<!-- perm fail -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.perm_failed'">
							<xsl:value-of select="$strings/labelPermFailed"/></xsl:when>
						<!-- deferred -->
						<xsl:when test="ns3:state='com.ibm.rqm.execution.common.state.deferred'">
							<xsl:value-of select="$strings/labelDeferred"/></xsl:when>
						<!-- default -->
						<xsl:otherwise>
							<xsl:apply-templates select="ns3:state"/></xsl:otherwise>
                    </xsl:choose>
				</fo:block>
			</fo:table-cell>
		</fo:table-row>
	</xsl:template>

</xsl:stylesheet>
